-- logic analyser trigger -- ver 1.0
-- Author: Ernest Jamro

--//////////////////////////////////////////////////////////////////////
--//// Copyright (C) 2001 Authors and OPENCORES.ORG                 ////
--////                                                              ////
--//// This source file may be used and distributed without         ////
--/// restriction provided that this copyright statement is not    ////
--//// removed from the file and that any derivative work contains  ////
--//// the original copyright notice and the associated disclaimer. ////
--////                                                              ////
--//// This source file is free software; you can redistribute it   ////
--//// and/or modify it under the terms of the GNU Lesser General   ////
--//// Public License as published by the Free Software Foundation; ////
--//// either version 2.1 of the License, or (at your option) any   ////
--//// later version.                                               ////
--////                                                              ////
--//// This source is distributed in the hope that it will be       ////
--//// useful, but WITHOUT ANY WARRANTY; without even the implied   ////
--//// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR      ////
--//// PURPOSE. See the GNU Lesser General Public License for more  ////
--//// details.                                                     ////
--////                                                              ////
--//// You should have received a copy of the GNU Lesser General    ////
--//// Public License along with this source; if not, download it   ////
--//// from <http://www.opencores.org/lgpl.shtml>                   ////



------------------------------------------------------------------------------------
------------------------------------------------------------------------------------
-- TRIGGER LOGIC for 64-bit data - make 64-bit trigger from two 32-bit triggers

library IEEE;
use IEEE.std_logic_1164.all;

entity la_trigger64 is
	generic (trig_width: integer:= 8); -- width of the trig data 1<=trig_width<=32
	port (clk, arst: in std_logic;
	-- LA interface
	trig_data: in std_logic_vector(trig_width-1 downto 0); -- data that are alasysed for triger
	trig_now: out std_logic; -- triger data is now presented on the trig_data bus
	-- Control interface (to set and read triger values)
	wr: in std_logic; -- when 1 writes din to triger configuration registers
	adr: in std_logic_vector(3 downto 0);
	dout: out std_logic_vector(7 downto 0);
	din: in std_logic_vector(7 downto 0) );
end la_trigger64;

architecture arch of la_trigger64 is
  component la_trigger
	generic (trig_width: integer:= 8); -- width of the trig data 1<=trig_width<=32
	port (clk, arst: in std_logic;
	-- LA interface
	trig_data: in std_logic_vector(trig_width-1 downto 0); -- data that are alasysed for triger
	trig_now: out std_logic; -- triger data is now presented on the trig_data bus
	-- Control interface (to set and read triger values)
	wr: in std_logic; -- when 1 writes din to triger configuration registers
	adr: in std_logic_vector(2 downto 0);
	dout: out std_logic_vector(7 downto 0);
	din: in std_logic_vector(7 downto 0) );
  end component;
  
  signal wr_vec, trig_now_vec: std_logic_vector(1 downto 0);
  signal dout_vec: std_logic_vector(15 downto 0);
  
begin
   g32: if trig_width<=32 generate
    t0: la_trigger
	  generic map (trig_width=>trig_width)
	  port map (clk=>clk, arst=> arst, 
        trig_data=> trig_data, trig_now=> trig_now, 
	    -- Control interface (to set and read triger values)
	    wr=> wr_vec(0), adr=> adr(2 downto 0), 
        dout=> dout, din=> din);
   end generate;	
   
   g64: if trig_width>32 generate
    t10: la_trigger
	  generic map (trig_width=>32)
	  port map (clk=>clk, arst=> arst, 
        trig_data=> trig_data(31 downto 0), trig_now=> trig_now_vec(0), 
	      -- Control interface (to set and read triger values)
	      wr=> wr_vec(0), adr=> adr(2 downto 0), 
        dout=> dout_vec(7 downto 0), din=> din);

    t11: la_trigger
	  generic map (trig_width=>trig_width-32)
	  port map (clk=>clk, arst=> arst, 
        trig_data=> trig_data(trig_width-1 downto 32), trig_now=> trig_now_vec(1), 
	      -- Control interface (to set and read triger values)
	      wr=> wr_vec(1), adr=> adr(2 downto 0), 
        dout=> dout_vec(15 downto 8), din=> din);

       wr_vec(1)<= wr and adr(3);
       dout<= dout_vec(7 downto 0) when adr(3)='0' else
              dout_vec(15 downto 8);
       trig_now<= trig_now_vec(0) and trig_now_vec(1);
   end generate;
         
  wr_vec(0)<=  wr and not adr(3);

         
end arch;