-------------------------------------------------------------------------------
-- opb_sram_0_wrapper.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
library UNISIM;
use UNISIM.VCOMPONENTS.ALL;

-- synthesis translate_on

entity opb_sram_0_wrapper is
  port (
    OPB_Clk : in std_logic;
    OPB_Rst : in std_logic;
    OPB_ABus : in std_logic_vector(0 to 31);
    OPB_BE : in std_logic_vector(0 to 3);
    OPB_RNW : in std_logic;
    OPB_select : in std_logic;
    OPB_seqAddr : in std_logic;
    OPB_DBus : in std_logic_vector(0 to 31);
    Sl_DBus : out std_logic_vector(0 to 31);
    Sl_errAck : out std_logic;
    Sl_Retry : out std_logic;
    Sl_toutSup : out std_logic;
    Sl_xferAck : out std_logic;
    pb_a : out std_logic_vector(0 to 17);
    pb_oen : out std_logic;
    pb_wen : out std_logic;
    ram_cen : out std_logic;
    pb_ubn : out std_logic;
    pb_lbn : out std_logic;
    pb_d_I : in std_logic_vector(0 to 15);
    pb_d_O : out std_logic_vector(0 to 15);
    pb_d_T : out std_logic
  );
end opb_sram_0_wrapper;

architecture STRUCTURE of opb_sram_0_wrapper is

  component opb_sram is
    generic (
      C_BASEADDR : std_logic_vector;
      C_HIGHADDR : std_logic_vector;
      C_OPB_AWIDTH : integer;
      C_OPB_DWIDTH : integer;
      C_REAL_DWIDTH : integer;
      C_SRAM_DWIDTH : integer;
      C_SRAM_AWIDTH : integer;
      C_USE_SEQADDR : integer;
      C_SPEEDRATE : integer
    );
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to C_OPB_AWIDTH-1);
      OPB_BE : in std_logic_vector(0 to C_OPB_DWIDTH/8-1);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to C_OPB_DWIDTH-1);
      Sl_DBus : out std_logic_vector(0 to C_OPB_DWIDTH-1);
      Sl_errAck : out std_logic;
      Sl_Retry : out std_logic;
      Sl_toutSup : out std_logic;
      Sl_xferAck : out std_logic;
      pb_a : out std_logic_vector(0 to C_SRAM_AWIDTH-1);
      pb_oen : out std_logic;
      pb_wen : out std_logic;
      ram_cen : out std_logic;
      pb_ubn : out std_logic;
      pb_lbn : out std_logic;
      pb_d_I : in std_logic_vector(0 to C_SRAM_DWIDTH-1);
      pb_d_O : out std_logic_vector(0 to C_SRAM_DWIDTH-1);
      pb_d_T : out std_logic
    );
  end component;

begin

  opb_sram_0 : opb_sram
    generic map (
      C_BASEADDR => X"8000_0000",
      C_HIGHADDR => X"8007_FFFF",
      C_OPB_AWIDTH => 32,
      C_OPB_DWIDTH => 32,
      C_REAL_DWIDTH => 16,
      C_SRAM_DWIDTH => 16,
      C_SRAM_AWIDTH => 18,
      C_USE_SEQADDR => 1,
      C_SPEEDRATE => 0
    )
    port map (
      OPB_Clk => OPB_Clk,
      OPB_Rst => OPB_Rst,
      OPB_ABus => OPB_ABus,
      OPB_BE => OPB_BE,
      OPB_RNW => OPB_RNW,
      OPB_select => OPB_select,
      OPB_seqAddr => OPB_seqAddr,
      OPB_DBus => OPB_DBus,
      Sl_DBus => Sl_DBus,
      Sl_errAck => Sl_errAck,
      Sl_Retry => Sl_Retry,
      Sl_toutSup => Sl_toutSup,
      Sl_xferAck => Sl_xferAck,
      pb_a => pb_a,
      pb_oen => pb_oen,
      pb_wen => pb_wen,
      ram_cen => ram_cen,
      pb_ubn => pb_ubn,
      pb_lbn => pb_lbn,
      pb_d_I => pb_d_I,
      pb_d_O => pb_d_O,
      pb_d_T => pb_d_T
    );

end architecture STRUCTURE;
