-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library UNISIM;
use UNISIM.VCOMPONENTS.ALL;

entity system is
  port (
    rs232_rd : in std_logic;
    rs232_td : out std_logic;
    pb_a : out std_logic_vector(0 to 17);
    pb_d : inout std_logic_vector(0 to 15);
    pb_oen : out std_logic;
    pb_wen : out std_logic;
    ram_cen : out std_logic;
    pb_ubn : out std_logic;
    pb_lbn : out std_logic;
    pp_dck : in std_logic;
    pp_dwr : in std_logic;
    pp_drd : out std_logic;
    sys_rst : out std_logic;
    clk : in std_logic
  );
end system;

architecture STRUCTURE of system is

  component microblaze_0_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      I_ADDRTAG : out std_logic_vector(0 to 3);
      IREADY : in std_logic;
      IWAIT : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DWAIT : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_ADDRTAG : out std_logic_vector(0 to 3);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 7);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      Trace_Branch_Instr : out std_logic;
      Trace_Delay_Slot : out std_logic;
      Trace_Data_Address : out std_logic_vector(0 to 31);
      Trace_AS : out std_logic;
      Trace_Data_Read : out std_logic;
      Trace_Data_Write : out std_logic;
      Trace_DCache_Req : out std_logic;
      Trace_DCache_Hit : out std_logic;
      Trace_ICache_Req : out std_logic;
      Trace_ICache_Hit : out std_logic;
      Trace_Instr_EX : out std_logic_vector(0 to 31);
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic
    );
  end component;

  component opb_uartlite_0_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      UART_DBus : out std_logic_vector(0 to 31);
      UART_errAck : out std_logic;
      UART_retry : out std_logic;
      UART_toutSup : out std_logic;
      UART_xferAck : out std_logic;
      RX : in std_logic;
      TX : out std_logic
    );
  end component;

  component opb_bram_if_cntlr_0_wrapper is
    port (
      opb_clk : in std_logic;
      opb_rst : in std_logic;
      opb_abus : in std_logic_vector(0 to 31);
      opb_dbus : in std_logic_vector(0 to 31);
      sln_dbus : out std_logic_vector(0 to 31);
      opb_select : in std_logic;
      opb_rnw : in std_logic;
      opb_seqaddr : in std_logic;
      opb_be : in std_logic_vector(0 to 3);
      sln_xferack : out std_logic;
      sln_errack : out std_logic;
      sln_toutsup : out std_logic;
      sln_retry : out std_logic;
      bram_rst : out std_logic;
      bram_clk : out std_logic;
      bram_en : out std_logic;
      bram_wen : out std_logic_vector(0 to 3);
      bram_addr : out std_logic_vector(0 to 31);
      bram_din : in std_logic_vector(0 to 31);
      bram_dout : out std_logic_vector(0 to 31)
    );
  end component;

  component opb_sram_0_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_errAck : out std_logic;
      Sl_Retry : out std_logic;
      Sl_toutSup : out std_logic;
      Sl_xferAck : out std_logic;
      pb_a : out std_logic_vector(0 to 17);
      pb_oen : out std_logic;
      pb_wen : out std_logic;
      ram_cen : out std_logic;
      pb_ubn : out std_logic;
      pb_lbn : out std_logic;
      pb_d_I : in std_logic_vector(0 to 15);
      pb_d_O : out std_logic_vector(0 to 15);
      pb_d_T : out std_logic
    );
  end component;

  component opb_epp_0_wrapper is
    port (
      OPB_clk : in std_logic;
      OPB_rst : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_MGrant : in std_logic;
      OPB_pendReq : in std_logic;
      OPB_errAck : in std_logic;
      OPB_retry : in std_logic;
      OPB_timeout : in std_logic;
      OPB_xferAck : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_busLock : in std_logic;
      OPB_toutSup : in std_logic;
      M_DBus : out std_logic_vector(0 to 31);
      M_BE : out std_logic_vector(0 to 3);
      M_ABus : out std_logic_vector(0 to 31);
      M_RNW : out std_logic;
      M_select : out std_logic;
      M_seqAddr : out std_logic;
      M_busLock : out std_logic;
      M_request : out std_logic;
      SYS_rst : out std_logic;
      pp_dck : in std_logic;
      pp_dwr : in std_logic;
      pp_drd : out std_logic;
      la_DBus : in std_logic_vector(0 to 63);
      la_TBus : in std_logic_vector(0 to 63);
      la_ceDBus : in std_logic_vector(0 to 63);
      la_ceTBus : in std_logic
    );
  end component;

  component util_clkdiv_0_wrapper is
    port (
      clk : in std_logic;
      clk_div_out : out std_logic
    );
  end component;

  component b_opb_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 2);
      Sl_DBus : in std_logic_vector(0 to 95);
      Sl_DBusEn : in std_logic_vector(0 to 2);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 2);
      Sl_errAck : in std_logic_vector(0 to 2);
      Sl_dwAck : in std_logic_vector(0 to 2);
      Sl_fwAck : in std_logic_vector(0 to 2);
      Sl_hwAck : in std_logic_vector(0 to 2);
      Sl_retry : in std_logic_vector(0 to 2);
      Sl_toutSup : in std_logic_vector(0 to 2);
      Sl_xferAck : in std_logic_vector(0 to 2);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  component bram_block_0_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  component lmb_bram_if_cntlr_0_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  component b_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  component IBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component OBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component IOBUF is
    port (
      I : in std_logic;
      IO : inout std_logic;
      O : out std_logic;
      T : in std_logic
    );
  end component;

  component BUFGP is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  -- Internal signals

  signal b_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal b_lmb_LMB_AddrStrobe : std_logic;
  signal b_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal b_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal b_lmb_LMB_ReadStrobe : std_logic;
  signal b_lmb_LMB_Ready : std_logic;
  signal b_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal b_lmb_LMB_WriteStrobe : std_logic;
  signal b_lmb_M_ABus : std_logic_vector(0 to 31);
  signal b_lmb_M_AddrStrobe : std_logic;
  signal b_lmb_M_ReadStrobe : std_logic;
  signal b_lmb_OPB_Rst : std_logic;
  signal b_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal b_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal b_opb_M_ABus : std_logic_vector(0 to 63);
  signal b_opb_M_BE : std_logic_vector(0 to 7);
  signal b_opb_M_DBus : std_logic_vector(0 to 63);
  signal b_opb_M_RNW : std_logic_vector(0 to 1);
  signal b_opb_M_busLock : std_logic_vector(0 to 1);
  signal b_opb_M_request : std_logic_vector(0 to 1);
  signal b_opb_M_select : std_logic_vector(0 to 1);
  signal b_opb_M_seqAddr : std_logic_vector(0 to 1);
  signal b_opb_OPB_ABus : std_logic_vector(0 to 31);
  signal b_opb_OPB_BE : std_logic_vector(0 to 3);
  signal b_opb_OPB_DBus : std_logic_vector(0 to 31);
  signal b_opb_OPB_MGrant : std_logic_vector(0 to 1);
  signal b_opb_OPB_RNW : std_logic;
  signal b_opb_OPB_Rst : std_logic;
  signal b_opb_OPB_busLock : std_logic;
  signal b_opb_OPB_errAck : std_logic;
  signal b_opb_OPB_pendReq : std_logic_vector(0 to 1);
  signal b_opb_OPB_retry : std_logic;
  signal b_opb_OPB_select : std_logic;
  signal b_opb_OPB_seqAddr : std_logic;
  signal b_opb_OPB_timeout : std_logic;
  signal b_opb_OPB_toutSup : std_logic;
  signal b_opb_OPB_xferAck : std_logic;
  signal b_opb_Sl_DBus : std_logic_vector(0 to 95);
  signal b_opb_Sl_errAck : std_logic_vector(0 to 2);
  signal b_opb_Sl_retry : std_logic_vector(0 to 2);
  signal b_opb_Sl_toutSup : std_logic_vector(0 to 2);
  signal b_opb_Sl_xferAck : std_logic_vector(0 to 2);
  signal clk_BUFGP : std_logic;
  signal conn_0_BRAM_Addr : std_logic_vector(0 to 31);
  signal conn_0_BRAM_Clk : std_logic;
  signal conn_0_BRAM_Din : std_logic_vector(0 to 31);
  signal conn_0_BRAM_Dout : std_logic_vector(0 to 31);
  signal conn_0_BRAM_EN : std_logic;
  signal conn_0_BRAM_Rst : std_logic;
  signal conn_0_BRAM_WEN : std_logic_vector(0 to 3);
  signal conn_1_BRAM_Addr : std_logic_vector(0 to 31);
  signal conn_1_BRAM_Clk : std_logic;
  signal conn_1_BRAM_Din : std_logic_vector(0 to 31);
  signal conn_1_BRAM_Dout : std_logic_vector(0 to 31);
  signal conn_1_BRAM_EN : std_logic;
  signal conn_1_BRAM_Rst : std_logic;
  signal conn_1_BRAM_WEN : std_logic_vector(0 to 3);
  signal net_gnd0 : std_logic;
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd3 : std_logic_vector(0 to 2);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_gnd5 : std_logic_vector(0 to 4);
  signal net_gnd64 : std_logic_vector(0 to 63);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal net_vcc3 : std_logic_vector(0 to 2);
  signal pb_a_OBUF : std_logic_vector(0 to 17);
  signal pb_d_I : std_logic_vector(0 to 15);
  signal pb_d_O : std_logic_vector(0 to 15);
  signal pb_d_T : std_logic;
  signal pb_lbn_OBUF : std_logic;
  signal pb_oen_OBUF : std_logic;
  signal pb_ubn_OBUF : std_logic;
  signal pb_wen_OBUF : std_logic;
  signal pp_dck_IBUF : std_logic;
  signal pp_drd_OBUF : std_logic;
  signal pp_dwr_IBUF : std_logic;
  signal ram_cen_OBUF : std_logic;
  signal rs232_rd_IBUF : std_logic;
  signal rs232_td_OBUF : std_logic;
  signal sys_clk : std_logic;
  signal sys_rst_OBUF : std_logic;

begin

  -- Internal assignments

  net_gnd0 <= '0';
  net_gnd2(0 to 1) <= B"00";
  net_gnd3(0 to 2) <= B"000";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_gnd5(0 to 4) <= B"00000";
  net_gnd64(0 to 63) <= B"0000000000000000000000000000000000000000000000000000000000000000";
  net_vcc2(0 to 1) <= B"11";
  net_vcc3(0 to 2) <= B"111";

  microblaze_0 : microblaze_0_wrapper
    port map (
      CLK => sys_clk,
      RESET => b_opb_OPB_Rst,
      INTERRUPT => net_gnd0,
      DEBUG_RST => net_gnd0,
      EXT_BRK => net_gnd0,
      EXT_NM_BRK => net_gnd0,
      DBG_STOP => net_gnd0,
      INSTR => b_lmb_LMB_ReadDBus,
      I_ADDRTAG => open,
      IREADY => b_lmb_LMB_Ready,
      IWAIT => net_gnd0,
      INSTR_ADDR => b_lmb_M_ABus,
      IFETCH => b_lmb_M_ReadStrobe,
      I_AS => b_lmb_M_AddrStrobe,
      DATA_READ => net_gnd32,
      DREADY => net_gnd0,
      DWAIT => net_gnd0,
      DATA_WRITE => open,
      DATA_ADDR => open,
      D_ADDRTAG => open,
      D_AS => open,
      READ_STROBE => open,
      WRITE_STROBE => open,
      BYTE_ENABLE => open,
      DM_ABUS => b_opb_M_ABus(0 to 31),
      DM_BE => b_opb_M_BE(0 to 3),
      DM_BUSLOCK => b_opb_M_busLock(0),
      DM_DBUS => b_opb_M_DBus(0 to 31),
      DM_REQUEST => b_opb_M_request(0),
      DM_RNW => b_opb_M_RNW(0),
      DM_SELECT => b_opb_M_select(0),
      DM_SEQADDR => b_opb_M_seqAddr(0),
      DOPB_DBUS => b_opb_OPB_DBus,
      DOPB_ERRACK => b_opb_OPB_errAck,
      DOPB_MGRANT => b_opb_OPB_MGrant(0),
      DOPB_RETRY => b_opb_OPB_retry,
      DOPB_TIMEOUT => b_opb_OPB_timeout,
      DOPB_XFERACK => b_opb_OPB_xferAck,
      IM_ABUS => open,
      IM_BE => open,
      IM_BUSLOCK => open,
      IM_DBUS => open,
      IM_REQUEST => open,
      IM_RNW => open,
      IM_SELECT => open,
      IM_SEQADDR => open,
      IOPB_DBUS => net_gnd32,
      IOPB_ERRACK => net_gnd0,
      IOPB_MGRANT => net_gnd0,
      IOPB_RETRY => net_gnd0,
      IOPB_TIMEOUT => net_gnd0,
      IOPB_XFERACK => net_gnd0,
      DBG_CLK => net_gnd0,
      DBG_TDI => net_gnd0,
      DBG_TDO => open,
      DBG_REG_EN => net_gnd5,
      DBG_CAPTURE => net_gnd0,
      DBG_UPDATE => net_gnd0,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      Trace_Branch_Instr => open,
      Trace_Delay_Slot => open,
      Trace_Data_Address => open,
      Trace_AS => open,
      Trace_Data_Read => open,
      Trace_Data_Write => open,
      Trace_DCache_Req => open,
      Trace_DCache_Hit => open,
      Trace_ICache_Req => open,
      Trace_ICache_Hit => open,
      Trace_Instr_EX => open,
      FSL0_S_CLK => open,
      FSL0_S_READ => open,
      FSL0_S_DATA => net_gnd32,
      FSL0_S_CONTROL => net_gnd0,
      FSL0_S_EXISTS => net_gnd0,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0
    );

  opb_uartlite_0 : opb_uartlite_0_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => b_opb_OPB_Rst,
      Interrupt => open,
      OPB_ABus => b_opb_OPB_ABus,
      OPB_BE => b_opb_OPB_BE,
      OPB_RNW => b_opb_OPB_RNW,
      OPB_select => b_opb_OPB_select,
      OPB_seqAddr => b_opb_OPB_seqAddr,
      OPB_DBus => b_opb_OPB_DBus,
      UART_DBus => b_opb_Sl_DBus(0 to 31),
      UART_errAck => b_opb_Sl_errAck(0),
      UART_retry => b_opb_Sl_retry(0),
      UART_toutSup => b_opb_Sl_toutSup(0),
      UART_xferAck => b_opb_Sl_xferAck(0),
      RX => rs232_rd_IBUF,
      TX => rs232_td_OBUF
    );

  opb_bram_if_cntlr_0 : opb_bram_if_cntlr_0_wrapper
    port map (
      opb_clk => sys_clk,
      opb_rst => b_opb_OPB_Rst,
      opb_abus => b_opb_OPB_ABus,
      opb_dbus => b_opb_OPB_DBus,
      sln_dbus => b_opb_Sl_DBus(32 to 63),
      opb_select => b_opb_OPB_select,
      opb_rnw => b_opb_OPB_RNW,
      opb_seqaddr => b_opb_OPB_seqAddr,
      opb_be => b_opb_OPB_BE,
      sln_xferack => b_opb_Sl_xferAck(1),
      sln_errack => b_opb_Sl_errAck(1),
      sln_toutsup => b_opb_Sl_toutSup(1),
      sln_retry => b_opb_Sl_retry(1),
      bram_rst => conn_0_BRAM_Rst,
      bram_clk => conn_0_BRAM_Clk,
      bram_en => conn_0_BRAM_EN,
      bram_wen => conn_0_BRAM_WEN,
      bram_addr => conn_0_BRAM_Addr,
      bram_din => conn_0_BRAM_Din,
      bram_dout => conn_0_BRAM_Dout
    );

  opb_sram_0 : opb_sram_0_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => b_opb_OPB_Rst,
      OPB_ABus => b_opb_OPB_ABus,
      OPB_BE => b_opb_OPB_BE,
      OPB_RNW => b_opb_OPB_RNW,
      OPB_select => b_opb_OPB_select,
      OPB_seqAddr => b_opb_OPB_seqAddr,
      OPB_DBus => b_opb_OPB_DBus,
      Sl_DBus => b_opb_Sl_DBus(64 to 95),
      Sl_errAck => b_opb_Sl_errAck(2),
      Sl_Retry => b_opb_Sl_retry(2),
      Sl_toutSup => b_opb_Sl_toutSup(2),
      Sl_xferAck => b_opb_Sl_xferAck(2),
      pb_a => pb_a_OBUF,
      pb_oen => pb_oen_OBUF,
      pb_wen => pb_wen_OBUF,
      ram_cen => ram_cen_OBUF,
      pb_ubn => pb_ubn_OBUF,
      pb_lbn => pb_lbn_OBUF,
      pb_d_I => pb_d_I,
      pb_d_O => pb_d_O,
      pb_d_T => pb_d_T
    );

  opb_epp_0 : opb_epp_0_wrapper
    port map (
      OPB_clk => sys_clk,
      OPB_rst => b_opb_OPB_Rst,
      OPB_DBus => b_opb_OPB_DBus,
      OPB_MGrant => b_opb_OPB_MGrant(1),
      OPB_pendReq => b_opb_OPB_pendReq(1),
      OPB_errAck => b_opb_OPB_errAck,
      OPB_retry => b_opb_OPB_retry,
      OPB_timeout => b_opb_OPB_timeout,
      OPB_xferAck => b_opb_OPB_xferAck,
      OPB_ABus => b_opb_OPB_ABus,
      OPB_RNW => b_opb_OPB_RNW,
      OPB_select => b_opb_OPB_select,
      OPB_seqAddr => b_opb_OPB_seqAddr,
      OPB_busLock => b_opb_OPB_busLock,
      OPB_toutSup => b_opb_OPB_toutSup,
      M_DBus => b_opb_M_DBus(32 to 63),
      M_BE => b_opb_M_BE(4 to 7),
      M_ABus => b_opb_M_ABus(32 to 63),
      M_RNW => b_opb_M_RNW(1),
      M_select => b_opb_M_select(1),
      M_seqAddr => b_opb_M_seqAddr(1),
      M_busLock => b_opb_M_busLock(1),
      M_request => b_opb_M_request(1),
      SYS_rst => sys_rst_OBUF,
      pp_dck => pp_dck_IBUF,
      pp_dwr => pp_dwr_IBUF,
      pp_drd => pp_drd_OBUF,
      la_DBus => net_gnd64,
      la_TBus => net_gnd64,
      la_ceDBus => net_gnd64,
      la_ceTBus => net_gnd0
    );

  util_clkdiv_0 : util_clkdiv_0_wrapper
    port map (
      clk => clk_BUFGP,
      clk_div_out => sys_clk
    );

  b_opb : b_opb_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => b_opb_OPB_Rst,
      SYS_Rst => sys_rst_OBUF,
      Debug_SYS_Rst => net_gnd0,
      WDT_Rst => net_gnd0,
      M_ABus => b_opb_M_ABus,
      M_BE => b_opb_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => b_opb_M_busLock,
      M_DBus => b_opb_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => b_opb_M_request,
      M_RNW => b_opb_M_RNW,
      M_select => b_opb_M_select,
      M_seqAddr => b_opb_M_seqAddr,
      Sl_beAck => net_gnd3,
      Sl_DBus => b_opb_Sl_DBus,
      Sl_DBusEn => net_vcc3,
      Sl_DBusEn32_63 => net_vcc3,
      Sl_errAck => b_opb_Sl_errAck,
      Sl_dwAck => net_gnd3,
      Sl_fwAck => net_gnd3,
      Sl_hwAck => net_gnd3,
      Sl_retry => b_opb_Sl_retry,
      Sl_toutSup => b_opb_Sl_toutSup,
      Sl_xferAck => b_opb_Sl_xferAck,
      OPB_MRequest => open,
      OPB_ABus => b_opb_OPB_ABus,
      OPB_BE => b_opb_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => b_opb_OPB_busLock,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => b_opb_OPB_DBus,
      OPB_errAck => b_opb_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => b_opb_OPB_MGrant,
      OPB_pendReq => b_opb_OPB_pendReq,
      OPB_retry => b_opb_OPB_retry,
      OPB_RNW => b_opb_OPB_RNW,
      OPB_select => b_opb_OPB_select,
      OPB_seqAddr => b_opb_OPB_seqAddr,
      OPB_timeout => b_opb_OPB_timeout,
      OPB_toutSup => b_opb_OPB_toutSup,
      OPB_xferAck => b_opb_OPB_xferAck
    );

  bram_block_0 : bram_block_0_wrapper
    port map (
      BRAM_Rst_A => conn_0_BRAM_Rst,
      BRAM_Clk_A => conn_0_BRAM_Clk,
      BRAM_EN_A => conn_0_BRAM_EN,
      BRAM_WEN_A => conn_0_BRAM_WEN,
      BRAM_Addr_A => conn_0_BRAM_Addr,
      BRAM_Din_A => conn_0_BRAM_Din,
      BRAM_Dout_A => conn_0_BRAM_Dout,
      BRAM_Rst_B => conn_1_BRAM_Rst,
      BRAM_Clk_B => conn_1_BRAM_Clk,
      BRAM_EN_B => conn_1_BRAM_EN,
      BRAM_WEN_B => conn_1_BRAM_WEN,
      BRAM_Addr_B => conn_1_BRAM_Addr,
      BRAM_Din_B => conn_1_BRAM_Din,
      BRAM_Dout_B => conn_1_BRAM_Dout
    );

  lmb_bram_if_cntlr_0 : lmb_bram_if_cntlr_0_wrapper
    port map (
      LMB_Clk => sys_clk,
      LMB_Rst => b_lmb_OPB_Rst,
      LMB_ABus => b_lmb_LMB_ABus,
      LMB_WriteDBus => b_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => b_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => b_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => b_lmb_LMB_WriteStrobe,
      LMB_BE => b_lmb_LMB_BE,
      Sl_DBus => b_lmb_Sl_DBus,
      Sl_Ready => b_lmb_Sl_Ready(0),
      BRAM_Rst_A => conn_1_BRAM_Rst,
      BRAM_Clk_A => conn_1_BRAM_Clk,
      BRAM_EN_A => conn_1_BRAM_EN,
      BRAM_WEN_A => conn_1_BRAM_WEN,
      BRAM_Addr_A => conn_1_BRAM_Addr,
      BRAM_Din_A => conn_1_BRAM_Din,
      BRAM_Dout_A => conn_1_BRAM_Dout
    );

  b_lmb : b_lmb_wrapper
    port map (
      LMB_Clk => sys_clk,
      SYS_Rst => sys_rst_OBUF,
      LMB_Rst => b_lmb_OPB_Rst,
      M_ABus => b_lmb_M_ABus,
      M_ReadStrobe => b_lmb_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => b_lmb_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => b_lmb_Sl_DBus,
      Sl_Ready => b_lmb_Sl_Ready(0 to 0),
      LMB_ABus => b_lmb_LMB_ABus,
      LMB_ReadStrobe => b_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => b_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => b_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => b_lmb_LMB_ReadDBus,
      LMB_WriteDBus => b_lmb_LMB_WriteDBus,
      LMB_Ready => b_lmb_LMB_Ready,
      LMB_BE => b_lmb_LMB_BE
    );

  ibuf_0 : IBUF
    port map (
      I => rs232_rd,
      O => rs232_rd_IBUF
    );

  obuf_1 : OBUF
    port map (
      I => rs232_td_OBUF,
      O => rs232_td
    );

  obuf_2 : OBUF
    port map (
      I => pb_a_OBUF(0),
      O => pb_a(0)
    );

  obuf_3 : OBUF
    port map (
      I => pb_a_OBUF(1),
      O => pb_a(1)
    );

  obuf_4 : OBUF
    port map (
      I => pb_a_OBUF(2),
      O => pb_a(2)
    );

  obuf_5 : OBUF
    port map (
      I => pb_a_OBUF(3),
      O => pb_a(3)
    );

  obuf_6 : OBUF
    port map (
      I => pb_a_OBUF(4),
      O => pb_a(4)
    );

  obuf_7 : OBUF
    port map (
      I => pb_a_OBUF(5),
      O => pb_a(5)
    );

  obuf_8 : OBUF
    port map (
      I => pb_a_OBUF(6),
      O => pb_a(6)
    );

  obuf_9 : OBUF
    port map (
      I => pb_a_OBUF(7),
      O => pb_a(7)
    );

  obuf_10 : OBUF
    port map (
      I => pb_a_OBUF(8),
      O => pb_a(8)
    );

  obuf_11 : OBUF
    port map (
      I => pb_a_OBUF(9),
      O => pb_a(9)
    );

  obuf_12 : OBUF
    port map (
      I => pb_a_OBUF(10),
      O => pb_a(10)
    );

  obuf_13 : OBUF
    port map (
      I => pb_a_OBUF(11),
      O => pb_a(11)
    );

  obuf_14 : OBUF
    port map (
      I => pb_a_OBUF(12),
      O => pb_a(12)
    );

  obuf_15 : OBUF
    port map (
      I => pb_a_OBUF(13),
      O => pb_a(13)
    );

  obuf_16 : OBUF
    port map (
      I => pb_a_OBUF(14),
      O => pb_a(14)
    );

  obuf_17 : OBUF
    port map (
      I => pb_a_OBUF(15),
      O => pb_a(15)
    );

  obuf_18 : OBUF
    port map (
      I => pb_a_OBUF(16),
      O => pb_a(16)
    );

  obuf_19 : OBUF
    port map (
      I => pb_a_OBUF(17),
      O => pb_a(17)
    );

  iobuf_20 : IOBUF
    port map (
      I => pb_d_O(0),
      IO => pb_d(0),
      O => pb_d_I(0),
      T => pb_d_T
    );

  iobuf_21 : IOBUF
    port map (
      I => pb_d_O(1),
      IO => pb_d(1),
      O => pb_d_I(1),
      T => pb_d_T
    );

  iobuf_22 : IOBUF
    port map (
      I => pb_d_O(2),
      IO => pb_d(2),
      O => pb_d_I(2),
      T => pb_d_T
    );

  iobuf_23 : IOBUF
    port map (
      I => pb_d_O(3),
      IO => pb_d(3),
      O => pb_d_I(3),
      T => pb_d_T
    );

  iobuf_24 : IOBUF
    port map (
      I => pb_d_O(4),
      IO => pb_d(4),
      O => pb_d_I(4),
      T => pb_d_T
    );

  iobuf_25 : IOBUF
    port map (
      I => pb_d_O(5),
      IO => pb_d(5),
      O => pb_d_I(5),
      T => pb_d_T
    );

  iobuf_26 : IOBUF
    port map (
      I => pb_d_O(6),
      IO => pb_d(6),
      O => pb_d_I(6),
      T => pb_d_T
    );

  iobuf_27 : IOBUF
    port map (
      I => pb_d_O(7),
      IO => pb_d(7),
      O => pb_d_I(7),
      T => pb_d_T
    );

  iobuf_28 : IOBUF
    port map (
      I => pb_d_O(8),
      IO => pb_d(8),
      O => pb_d_I(8),
      T => pb_d_T
    );

  iobuf_29 : IOBUF
    port map (
      I => pb_d_O(9),
      IO => pb_d(9),
      O => pb_d_I(9),
      T => pb_d_T
    );

  iobuf_30 : IOBUF
    port map (
      I => pb_d_O(10),
      IO => pb_d(10),
      O => pb_d_I(10),
      T => pb_d_T
    );

  iobuf_31 : IOBUF
    port map (
      I => pb_d_O(11),
      IO => pb_d(11),
      O => pb_d_I(11),
      T => pb_d_T
    );

  iobuf_32 : IOBUF
    port map (
      I => pb_d_O(12),
      IO => pb_d(12),
      O => pb_d_I(12),
      T => pb_d_T
    );

  iobuf_33 : IOBUF
    port map (
      I => pb_d_O(13),
      IO => pb_d(13),
      O => pb_d_I(13),
      T => pb_d_T
    );

  iobuf_34 : IOBUF
    port map (
      I => pb_d_O(14),
      IO => pb_d(14),
      O => pb_d_I(14),
      T => pb_d_T
    );

  iobuf_35 : IOBUF
    port map (
      I => pb_d_O(15),
      IO => pb_d(15),
      O => pb_d_I(15),
      T => pb_d_T
    );

  obuf_36 : OBUF
    port map (
      I => pb_oen_OBUF,
      O => pb_oen
    );

  obuf_37 : OBUF
    port map (
      I => pb_wen_OBUF,
      O => pb_wen
    );

  obuf_38 : OBUF
    port map (
      I => ram_cen_OBUF,
      O => ram_cen
    );

  obuf_39 : OBUF
    port map (
      I => pb_ubn_OBUF,
      O => pb_ubn
    );

  obuf_40 : OBUF
    port map (
      I => pb_lbn_OBUF,
      O => pb_lbn
    );

  ibuf_41 : IBUF
    port map (
      I => pp_dck,
      O => pp_dck_IBUF
    );

  ibuf_42 : IBUF
    port map (
      I => pp_dwr,
      O => pp_dwr_IBUF
    );

  obuf_43 : OBUF
    port map (
      I => pp_drd_OBUF,
      O => pp_drd
    );

  obuf_44 : OBUF
    port map (
      I => sys_rst_OBUF,
      O => sys_rst
    );

  bufgp_45 : BUFGP
    port map (
      I => clk,
      O => clk_BUFGP
    );

end architecture STRUCTURE;
